@@ -1,4 +1,4 @@
-from pyHPump.util import *
+from .util import *
 
 
 class Command:
